@@ -5,27 +5,27 @@ use warnings;
 use Data::Dumper;
 use DateTime;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
-
-# Items to export into callers namespace by default. Note: do not export.
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# This allows declaration	use NKTI::general ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw( cetak cetak_r cetak_pre ) ]);
-our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-our @EXPORT = qw(cetak cetak_r cetak_pre);
-
 # Define Version :
 # ---------------------------------------------------------------- 
-our $VERSION = '0.12.1';
+our $VERSION = '0.01';
+
+# Define Abstract :
+# ----------------------------------------------------------------
+our $ABSTRACT = 'Module will be used for General Case.';
 
 # Create Subroutine for Get OS Server Information :
 # ------------------------------------------------------------------------
+=head1 SUBROUTINE os_server_info()
+
+    Description Subroutine :
+    ----------------------------------------
+    SUbroutine yang berfungsi untuk menampilkan Informasi OS Server.
+
+    Parameter Subroutine :
+    ----------------------------------------
+    Tidak ada parameter Subroutine.
+    
+=cut
 sub os_server_info {
     # ----------------------------------------------------------------
     # Prepare to get Operating System Information :
@@ -63,6 +63,13 @@ sub os_server_info {
 
 # Create Subroutine for get OS Client Information :
 # ------------------------------------------------------------------------
+=head1 SUBROUTINE os_client_info()
+
+    Parameter Subroutine :
+    ----------------------------------------
+    No Argument or Parameter.
+
+=cut
 sub os_info {
     
     # Define self :
@@ -110,6 +117,13 @@ sub os_info {
 
 # Create Subroutine for Get Browser Information :
 # ------------------------------------------------------------------------
+=head1 SUBROUTINE browser_info()
+
+    Parameter Subroutine :
+    ----------------------------------------
+    No Parameter Subroutine.
+    
+=cut
 sub browser_info {
     
     # Prepare to get Browser Information :
@@ -146,6 +160,18 @@ sub browser_info {
 
 # Create Subroutine for Delimiter Directory :
 # ------------------------------------------------------------------------
+=head1 SUBROUTINE delimiter_dir()
+
+    Description Subroutine :
+    ----------------------------------------
+    Subroutine yang berfungsi untuk deteksi Delimiter direktori
+    berdasarkan Sistem Operasi.
+
+    Parameter Subroutine :
+    ----------------------------------------
+    No Parameter Subroutine.
+
+=cut
 sub delimiter_dir {
     
     # Run Subroutine "os_server_info()" :
@@ -180,7 +206,15 @@ sub delimiter_dir {
 
 # Create Subroutine for get database config :
 # ------------------------------------------------------------------------
-sub get_dbconfig_php {
+=head1 get_dbconfig()
+
+    Parameter Subroutine :
+    ----------------------------------------
+    $fileloc     =>  Nama file Database Config.
+    $dirloc      =>  Lokasi Direktori Database config.
+
+=cut
+sub get_dbconfig {
     
     # Define arguments subroutine :
     # ----------------------------------------------------------------
@@ -210,6 +244,17 @@ sub get_dbconfig_php {
 
 # Subroutine for get protocols :
 # ------------------------------------------------------------------------
+=head1 SUBROUTINE get_protocol()
+    
+    Deskripsi subroutine get_protocol() :
+    ----------------------------------------
+    Subroutine yang berfungsi untuk mengambil data protocol.
+
+    Parameter subroutine get_protocol() :
+    ----------------------------------------
+    No parameter Subroutine.
+
+=cut
 sub get_protocol {
     
     # Prepare to get Protocol used :
@@ -226,11 +271,22 @@ sub get_protocol {
     # ----------------------------------------------------------------
     return $get_protocol; 
 }
-# End of Subroutine for get protocols.
+# End of Subroutine for get protocols
 # ===========================================================================================================
 
-# Subroutine for check IF module is exists :
+# Create Module for check IF module is exists :
 # ------------------------------------------------------------------------
+=head1 MODULE try_module()
+
+    Description Subroutine :
+    ----------------------------------------
+    Subroutine yang berfungsi untuk mengecek Module.
+
+    Parameter Subroutine :
+    ----------------------------------------
+    $module_name    => Berisi nama module, Ex: Your::module::name.
+
+=cut
 sub try_module {
     
     # Define parameter module :
@@ -254,11 +310,29 @@ sub try_module {
         return(1);
     }
 }
-# End of Subroutine for check IF module is exists
+# End of Create Module for check IF module is exists
 # ===========================================================================================================
 
 # Subroutine for define time for Event MySQL :
 # ------------------------------------------------------------------------
+=head1 SUBROUTINE time_event_mysql()
+    
+    Deskripsi subroutine time_event_mysql() :
+    ---------------------------------------------
+    Subroutine yang berfungsi untuk mendefinisikan Time Event MySQL.
+
+    Parameter subroutine time_event_mysql() :
+    ---------------------------------------------
+    $time_event         =>  Berisi Time Event.
+                            Ex: "1Y" => "tahun",
+                                "1M" => "bulan",
+                                "1W" => "minggu",
+                                "1D" => "Hari",
+                                "1H" => "Jam",
+                                "1m" => "menit",
+                                "1d" => "detik"
+
+=cut
 sub time_event_mysql {
     # ----------------------------------------------------------------
     # Define parameter Subroutine :
@@ -366,6 +440,19 @@ sub time_event_mysql {
 
 # Subroutine for Define format DATETIME MySQL :
 # ------------------------------------------------------------------------
+=head1 SUBRUTINE datetime_mysql()
+
+	Deskripsi subroutine datetime_mysql() :
+	----------------------------------------
+	Subroutine yang berfungsi untuk mengkonversi "timestamp" ke
+	Format "DATETIME" MySQL.
+
+    Parameter subroutine datetime_mysql() :
+    ----------------------------------------
+    $timestamp          =>  Berisi Timestamp Format.
+    $timezone           =>  Berisi data Timezone. Ex: "Asia/Jakarta".
+
+=cut
 sub datetime_mysql {
     # ----------------------------------------------------------------
     # Define parameter subroutine :
@@ -399,66 +486,14 @@ sub datetime_mysql {
 # End of Subroutine for Define format DATETIME MySQL
 # ===========================================================================================================
 
-# Subroutine for Print data with newline :
-# ------------------------------------------------------------------------
-sub cetak {
-	# ----------------------------------------------------------------
-	# Define parameter subroutine :
-	# ----------------------------------------------------------------
-	my ($data) = @_;
-    # ----------------------------------------------------------------
-    # Print Data :
-    # ----------------------------------------------------------------
-    print "$data \n";
-}
-# End of Subroutine for Print data with newline
-# ===========================================================================================================
-
-# Subroutine for Print ref :
-# ------------------------------------------------------------------------
-sub cetak_r {
-    # ----------------------------------------------------------------
-    # Check Parameter Subroutine :
-    # ----------------------------------------------------------------
-    if (keys(@_) eq 1) {
-        # ----------------------------------------------------------------
-        # Print Dumper :
-        # ----------------------------------------------------------------
-        print Dumper $_[0];
-    }
-    if (keys(@_) > 1) {
-        # ----------------------------------------------------------------
-        # Print Dumper :
-        # ----------------------------------------------------------------
-        print Dumper \@_;
-    }
-}
-# End of Subroutine for Print ref.
-# ===========================================================================================================
-
-# Subroutine for print ref with pre tag HTML :
-# ------------------------------------------------------------------------
-sub cetak_pre {
-    # ----------------------------------------------------------------
-    # Check Parameter Subroutine :
-    # ----------------------------------------------------------------
-    if (keys(@_) eq 1) {
-        # ----------------------------------------------------------------
-        # Print Dumper :
-        # ----------------------------------------------------------------
-        print "<pre>";
-        print Dumper $_[0];
-        print "</pre>";
-    }
-    if (keys(@_) > 1) {
-        # ----------------------------------------------------------------
-        # Print Dumper :
-        # ----------------------------------------------------------------
-        print Dumper \@_;
-    }
-}
-# End of Subroutine for print ref with pre tag HTML
-# ===========================================================================================================
 1;
 __END__
-#
\ No newline at end of file
+=head1 AUTHOR
+    Achmad Yusri Afandi, (linuxer08@gmail.com)
+
+=head1 COPYRIGHT AND LICENSE
+    Copyright (c) 2016, Achmad Yusri Afandi, All Rights reserved.
+
+    Pustaka yang berfungsi untuk hal-hal umum dalam web aplikasi.
+
+=cut
\ No newline at end of file
